Functions exported silently to allow for cross-package inheritance
of the expressionset object. These functions are never
needed in scripts or statistical production code.
Service for filling an expressionset from commandline
.PKGOPT(..., .__defaults = FALSE, .__reset = FALSE).ini_expressionset_cli(obj, ..., .prefix = "R")
.ini_expressionset_yml(obj, file, .prefix = "R")
.show_expressionset(obj)
.get_exprs(x, ..., expand_assignments = FALSE, expand_groups = TRUE,
vectorize = TRUE, replace_dollar = TRUE,
lin_eq_eps = x$options("lin.eq.eps"), dat = NULL)
.blocks_expressionset(x)
Comma-separated list of expressions
toggle default options
togle reset options
An expressionset object (or an object inheriting from expressionset).
Prefix to use in default names.
a filename
An expressionset object
Substitute assignments?
Expand groups?
Vectorize if-statements?
Replace dollar with bracket index?
Optionally, a data.frame containing the data to which the
expressions will be applied. When provided, the only equalities A==B
that will be translated to abs(A-B)<lin.eq.eps are those where all
occurring variables are numeric in dat.
An expressionset object (or an object inheriting from expressionset).
Prefix to use in default names.
an expressionset object
a character vector of variables to search through when groups are defined with regexps.
This function is aimed at developers importing the package and not at direct users of validate.