indication-class: Store results of evaluating indicators
Description
This feature is currently experimental and may change in the future
Details
An indication stores a set of results generated by evaluating
an indicator in the context of data along with some metadata.Exported S4 methods for <code>indication</code>