match_cells: Create matching subsets of a sequence of data
Description
Create matching subsets of a sequence of data
Usage
match_cells(..., .list = NULL, id = NULL)
Arguments
...
A sequence of data.frames, possibly in the form of <name>=<value> pairs.
.list
A list of data.frames; will be concatenated with ....
id
Names or indices of columns to use as index.
Value
A list of data.frames, subsetted and sorted so that all cells correspond.