Missingness counters (DEPRECATED)
number_missing(...)fraction_missing(...)
row_missing(...)
col_missing(...)
number_unique(...)
any_missing(...)
any_duplicated(...)
comma-separated list of variable names (not character). If no variables are specified, the number of missings over all data is counted.
For number_missing, the total number of missings over all specified variables.
For fraction_missing, the fraction of missings over all specified variables
For row_missing a vector with the number of missings per (sub)record defined by ....
For col_missing a vector with the number of missings per column
defined by ....
For number_unique the number of records, unique for
the columns specified in ....
For any_missing, TRUE if any NA occur in the columns
specified in ....
For any_duplicated, TRUE if any (sub)records specified by
... are duplicated, FALSE otherwise. Note that NA is matched with NA.