Learn R Programming

validate (version 0.1.5)

rule-class: A rich expression

Description

A rich expression

Arguments

Details

Technically, rule is a call object endowed with extra attributes such as a name, a label and a description description, creation time and a reference to its origin. Rule objects are not for direct use by users of the package, but may be of interest for developers of this package, or packages depending on it.

Exported S4 methods for <code>rule</code>

Private S4 methods for <code>rule</code>

  • validating
  • linear
  • expr
  • is_tran_assign