Learn R Programming

validate (version 0.1.5)

variables: Extract variable names

Description

Extract variable names

Usage

variables(x, ...)
"variables"(x, ...)
"variables"(x, ...)
"variables"(x, ...)
"variables"(x, ...)
"variables"(x, as = c("vector", "matrix", "list"), dummy = FALSE, ...)

Arguments

x
An R object
...
Arguments to be passed to other methods.
as
how to return variables:
  • 'vector' Return the uniqe vector of variables occurring in x.
  • 'matrix' Return a boolean matrix, each row representing a rule, each column representing a variable.
  • 'list' Return a named list, each entry containing a character vector with variable names.
dummy
Also retrieve transient variables set with the := operator.

Methods (by class)

  • rule: Retrieve unique variable names
  • list: Alias to names.list
  • data.frame: Alias to names.data.frame
  • environment: Alias to ls
  • expressionset: Variables occuring in x either as a single list, or per rule.

See Also

Examples

Run this code

v <- validator(
  root = y := sqrt(x)
 , average = mean(x) > 3
 , sum = x + y == z
)
variables(v)
variables(v,dummy=TRUE)
variables(v,matrix=TRUE)
variables(v,matrix=TRUE,dummy=TRUE)


Run the code above in your browser using DataLab