Learn R Programming

validate (version 0.1.4)

.PKGOPT: Services for extending 'validate'

Description

Functions exported silently to allow for cross-package inheritance of the expressionset object. These functions are never needed in scripts or statistical production code.

Service for filling an expressionset from commandline

Usage

.PKGOPT(..., .__defaults = FALSE, .__reset = FALSE)

.ini_expressionset_cli(obj, ..., .prefix = "R")

.ini_expressionset_yml(obj, file, .prefix = "R")

.show_expressionset(obj)

.get_exprs(x, ..., expand_assignments = FALSE, expand_groups = TRUE, vectorize = TRUE, replace_dollar = TRUE, lin_eq_eps = x$options("lin.eq.eps"))

.blocks_expressionset(x)

Arguments

...
Comma-separated list of expressions
.__defaults
toggle default options
.__reset
togle reset options
obj
An expressionset object (or an object inheriting from expressionset).
.prefix
Prefix to use in default names.
file
a filename
x
An expressionset object
expand_assignments
Substitute assignments?
expand_groups
Expand groups?
vectorize
Vectorize if-statements?
replace_dollar
Replace dollar with bracket index?
obj
An expressionset object (or an object inheriting from expressionset).
.prefix
Prefix to use in default names.
obj
an expressionset object
varlist:
a character vector of variables to search through when groups are defined with regexps.

Details

This function is aimed at developers importing the package and not at direct users of validate.