validation-class: Store results of evaluating validating expressions
Description
Store results of evaluating validating expressions
Details
A object of class validation stores a set of results generated by
evaluating an validator in the context of data along with some
metadata.Exported S4 methods for <code>validation</code>